@@ -2,7 +2,6 @@
 import asyncio
 import datetime
 import logging
-import math
 from xml.parsers.expat import ExpatError
 
 import aiohttp
@@ -54,7 +53,8 @@ CONDITIONS = {
     49: "snowy",
     50: "snowy",
 }
-DEFAULT_API_URL = "https://api.met.no/weatherapi/locationforecast/1.9/"
+DEFAULT_API_URL = "https://api.met.no/weatherapi/locationforecast/2.0/classic"
+
 EARTH_RADIUS = 6371 * 1000  # earth radius
 
 _LOGGER = logging.getLogger(__name__)
@@ -65,6 +65,10 @@ class MetWeatherData:
 
     def __init__(self, urlparams, websession=None, api_url=DEFAULT_API_URL):
         """Initialize the Weather object."""
+        urlparams = {"lat": str(round(float(urlparams['lat']), 4)),
+                     "lon": str(round(float(urlparams['lon']), 4)),
+                     "altitude": str(int(float(urlparams.get('altitude', urlparams.get('msl', 0))))),
+                     }
         self._urlparams = urlparams
         self._api_url = api_url
         if websession is None:
@@ -142,19 +146,19 @@ class MetWeatherData:
 
                 if "temperature" in time_entry["location"]:
                     daily_temperatures.append(
-                        float(time_entry["location"]["temperature"]["@value"])
+                        get_value(time_entry["location"]["temperature"], "@value")
                     )
                 if "precipitation" in time_entry["location"]:
                     daily_precipitation.append(
-                        float(time_entry["location"]["precipitation"]["@value"])
+                        get_value(time_entry["location"]["precipitation"], "@value")
                     )
                 if "windSpeed" in time_entry["location"]:
                     daily_windspeed.append(
-                        float(time_entry["location"]["windSpeed"]["@mps"])
+                        get_value(time_entry["location"]["windSpeed"], "@mps")
                     )
                 if "windGust" in time_entry["location"]:
                     daily_windgust.append(
-                        float(time_entry["location"]["windGust"]["@mps"])
+                        get_value(time_entry["location"]["windGust"], "@mps")
                     )
 
             average_dist = abs((valid_to - time).total_seconds()) + abs(
@@ -200,6 +204,16 @@ class MetWeatherData:
         return res
 
 
+def get_value(data, value):
+    """Retrieve weather value."""
+    try:
+        if value == "@mps":
+            return round(float(data[value]) * 3.6, 1)
+        return round(float(data[value]), 1)
+    except (ValueError, IndexError, KeyError):
+        return None
+
+
 def get_data(param, data):
     """Retrieve weather parameter."""
     try:
@@ -216,11 +230,11 @@ def get_data(param, data):
                     "dewpointTemperature",
                     "precipitation",
             ):
-                new_state = round(float(loc_data[param]["@value"]), 1)
+                new_state = get_value(loc_data[param], "@value")
             elif param in ("windSpeed", "windGust"):
-                new_state = round(float(loc_data[param]["@mps"]) * 3.6, 1)
+                new_state = get_value(loc_data[param], "@mps")
             elif param == "windDirection":
-                new_state = round(float(loc_data[param]["@deg"]), 1)
+                new_state = get_value(loc_data[param], "@deg")
             elif param in (
                     "fog",
                     "cloudiness",
@@ -228,7 +242,7 @@ def get_data(param, data):
                     "mediumClouds",
                     "highClouds",
             ):
-                new_state = round(float(loc_data[param]["@percent"]), 1)
+                new_state = get_value(loc_data[param], "@percent")
             return new_state
     except (ValueError, IndexError, KeyError):
         return None
@@ -336,64 +350,6 @@ class AirQualityData:
         return True
 
 
-class LightningData:
-    """Get the latest data."""
-
-    # pylint: disable=too-many-locals, too-few-public-methods
-
-    def __init__(self, websession):
-        """Initialize the Lightning object."""
-        self._websession = websession
-        self._api_url = "https://api.met.no/weatherapi/lightning/1.0/"
-
-    async def within_radius(self, latitude, longitude, radius):
-        """Get lightning with radius."""
-        try:
-            with async_timeout.timeout(10):
-                resp = await self._websession.get(self._api_url)
-            if resp.status >= 400:
-                _LOGGER.error("%s returned %s", self._api_url, resp.status)
-                return []
-            data = await resp.text()
-        except (asyncio.TimeoutError, aiohttp.ClientError) as err:
-            _LOGGER.error("%s returned %s", self._api_url, err)
-            return []
-
-        res = {}
-        for row in data.split("\n"):
-            elements = row.split(" ")
-            if len(elements) < 25:
-                continue
-
-            lat = float(elements[8])
-            long = float(elements[9])
-
-            dlat = math.radians(lat - latitude)
-            dlon = math.radians(long - longitude)
-            var_a = math.sin(dlat / 2) * math.sin(dlat / 2) + math.cos(
-                math.radians(lat)
-            ) * math.cos(math.radians(latitude)) * math.sin(dlon / 2) * math.sin(
-                dlon / 2
-            )
-            var_c = 2 * math.atan2(math.sqrt(var_a), math.sqrt(1 - var_a))
-            distance = EARTH_RADIUS * var_c
-            if distance > radius:
-                continue
-
-            date = datetime.datetime.strptime(
-                "".join(elements[1:7]), "%Y%m%d%H%M%S"
-            ).astimezone(pytz.utc)
-
-            res["".join(elements[1:8])] = {
-                "distance": distance,
-                "lat": lat,
-                "long": long,
-                "date": date,
-            }
-
-        return res
-
-
 def parse_datetime(dt_str):
     """Parse datetime."""
     date_format = "%Y-%m-%dT%H:%M:%S %z"
